# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Required, TypedDict

from .._types import FileTypes

__all__ = ["KnowledgeBaseCreateParams", "KnowledgeBaseText"]


class KnowledgeBaseCreateParams(TypedDict, total=False):
    knowledge_base_name: Required[str]
    """Name of the knowledge base. Must be less than 40 characters."""

    enable_auto_refresh: bool
    """Whether to enable auto refresh for the knowledge base urls.

    If set to true, will retrieve the data from the specified url every 12 hours.
    """

    knowledge_base_files: List[FileTypes]
    """Files to add to the knowledge base.

    Limit to 25 files, where each file is limited to 50MB.
    """

    knowledge_base_texts: Iterable[KnowledgeBaseText]
    """Texts to add to the knowledge base."""

    knowledge_base_urls: List[str]
    """URLs to be scraped and added to the knowledge base. Must be valid urls."""


class KnowledgeBaseText(TypedDict, total=False):
    text: Required[str]
    """Text to add to the knowledge base."""

    title: Required[str]
    """Title of the text."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["PhoneNumberImportParams"]


class PhoneNumberImportParams(TypedDict, total=False):
    phone_number: Required[str]
    """
    The number you are trying to import in E.164 format of the number (+country
    code, then number with no space, no special characters), used as the unique
    identifier for phone number APIs.
    """

    termination_uri: Required[str]
    """The termination uri to uniquely identify your elastic SIP trunk.

    This is used for outbound calls. For Twilio elastic SIP trunks it always end
    with ".pstn.twilio.com".
    """

    inbound_agent_id: Optional[str]
    """Unique id of agent to bind to the number.

    The number will automatically use the agent when receiving inbound calls. If
    null, this number would not accept inbound call.
    """

    inbound_webhook_url: Optional[str]
    """
    If set, will send a webhook for inbound calls, where you can to override agent
    id, set dynamic variables and other fields specific to that call.
    """

    nickname: str
    """Nickname of the number. This is for your reference only."""

    outbound_agent_id: Optional[str]
    """Unique id of agent to bind to the number.

    The number will automatically use the agent when conducting outbound calls. If
    null, this number would not be able to initiate outbound call without agent id
    override.
    """

    sip_trunk_auth_password: str
    """The password used for authentication for the SIP trunk."""

    sip_trunk_auth_username: str
    """The username used for authentication for the SIP trunk."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, Required, TypedDict

__all__ = ["CallRegisterPhoneCallParams"]


class CallRegisterPhoneCallParams(TypedDict, total=False):
    agent_id: Required[str]
    """The agent to use for the call."""

    direction: Literal["inbound", "outbound"]
    """Direction of the phone call. Stored for tracking purpose."""

    from_number: str
    """The number you own in E.164 format. Stored for tracking purpose."""

    metadata: object
    """An arbitrary object for storage purpose only.

    You can put anything here like your internal customer id associated with the
    call. Not used for processing. You can later get this field from the call
    object.
    """

    retell_llm_dynamic_variables: Dict[str, object]
    """
    Add optional dynamic variables in key value pairs of string that injects into
    your Response Engine prompt and tool description. Only applicable for Response
    Engine.
    """

    to_number: str
    """The number you want to call, in E.164 format. Stored for tracking purpose."""
